{
  config,
  pkgs,
  ...
}: let
  inherit (pkgs.stdenv.hostPlatform) isDarwin isLinux;
in {
  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  home.username = "acicchetti";

  home.homeDirectory =
    if isDarwin
    then "/Users/acicchetti"
    else "/home/acicchetti";

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  home.stateVersion = "22.11"; # Please read the comment before changing.

  # The home.packages option allows you to install Nix packages into your
  # environment.
  home.packages = [
    # # It is sometimes useful to fine-tune packages, for example, by applying
    # # overrides. You can do that directly here, just don't forget the
    # # parentheses. Maybe you want to install Nerd Fonts with a limited number of
    # # fonts?
    # (pkgs.nerdfonts.override { fonts = [ "FantasqueSansMono" ]; })

    # # You can also create simple shell scripts directly inside your
    # # configuration. For example, this adds a command 'my-hello' to your
    # # environment:
    # (pkgs.writeShellScriptBin "my-hello" ''
    #   echo "Hello, ${config.home.username}!"
    # '')
  ];

  # Home Manager is pretty good at managing dotfiles. The primary way to manage
  # plain files is through 'home.file'.
  home.file = {
    # # Building this configuration will create a copy of 'dotfiles/screenrc' in
    # # the Nix store. Activating the configuration will then make '~/.screenrc' a
    # # symlink to the Nix store copy.
    # ".screenrc".source = dotfiles/screenrc;

    # # You can also set the file content immediately.
    # ".gradle/gradle.properties".text = ''
    #   org.gradle.console=verbose
    #   org.gradle.daemon.idletimeout=3600000
    # '';
  };

  # You can also manage environment variables but you will have to manually
  # source
  #
  #  ~/.nix-profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  /etc/profiles/per-user/acicchetti/etc/profile.d/hm-session-vars.sh
  #
  # if you don't want to manage your shell through Home Manager.
  home.sessionVariables = {
    EDITOR = "nvim";
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  programs.aria2 = {
    enable = true;
  };

  programs.atuin = {
    enable = true;
    enableZshIntegration = true;
  };

  programs.direnv = {
    enable = true;
    nix-direnv.enable = true;
  };

  programs.eza = {
    enable = true;
    git = true;
    icons = true;
    enableAliases = false;
  };

  programs.gh = {
    enable = true;
    settings = {
      editor = "nvim";
      git_protocol = "ssh";
    };
  };

  programs.htop = {
    enable = true;
  };

  programs.mcfly = {
    enable = false;
    keyScheme = "vim";
  };

  programs.nix-index-database = {
    comma.enable = true;
  };

  programs.nnn = {
    enable = true;
  };

  programs.skim = {
    enable = true;
    enableZshIntegration = false;
  };

  programs.tealdeer = {
    enable = true;
  };

  programs.topgrade = {
    enable = true;
    settings = {
      misc = {
        disable = ["node" "nix" "home_manager" "gem" "ruby_gems" "cargo" "vim" "pipx" "pip3" "containers"];
        run_in_tmux = true;
        display_time = true;
        skip_notify = true;
      };
      git.max_concurrency = 5;
      linux.arch_package_manager = "paru";
    };
  };

  programs.zoxide = {
    enable = true;
  };

  programs.zsh = {
    enable = false;
  };

  programs.doom-emacs = {
    enable = true;
    doomPrivateDir = ../../emacs/emacs.doom;
    emacsPackage =
      if isDarwin
      then pkgs.emacs
      else pkgs.emacs;
  };

  imports = [
    ./modules/packages
    ./modules/files.nix
    ./modules/environment.nix
  ];
}
