{
  config,
  lib,
  pkgs,
  ...
}: {
  programs.nixneovim = {
    enable = true;
    defaultEditor = true;
    viAlias = true;
    vimAlias = true;
    extraLuaPreConfig = builtins.readFile ./neovim/pre.lua;
    extraConfigLua = builtins.readFile ./neovim/core.lua;
    colorscheme = "onedark";
    colorschemes = {
      onedark.enable = true;
    };
    plugins = {
      fugitive = {
        enable = true;
      };
      lspconfig = {
        enable = true;
        servers = {
          bashls.enable = true;
          gopls.enable = true;
          jsonls.enable = true;
          pyright.enable = true;
          rnix-lsp.enable = true;
          rust-analyzer.enable = true;
          taplo.enable = true;
          terraform-ls.enable = true;
        };
      };
      mini = {
        enable = true;
        ai.enable = true;
        align.enable = true;
        animate.enable = true;
        comment.enable = true;
        completion.enable = true;
        indentscope.enable = true;
        jump.enable = true;
        jump2d = {
          enable = true;
          extraConfig = {
            mappings.start_jumping = "<leader>a";
          };
        };
        splitjoin.enable = true;
        surround.enable = true;
      };
      project-nvim = {
        enable = true;
      };
      telescope = {
        enable = true;
        extraLua = {
          post = builtins.readFile ./neovim/telescope.lua;
        };
      };
      treesitter = {
        enable = true;
        indent = true;
        folding = true;
        incrementalSelection = {
          enable = true;
        };
      };
      undotree = {
        enable = true;
      };
      which-key = {
        enable = true;
        groups = {
          normal = {
            "<leader>f" = "Telescope - Find";
            "<leader>r" = "View registers";
            "<leader>p" = "Telescope - LSP";
          };
        };
      };
    };
    extraPlugins =
      (
        with pkgs.vimPlugins; [
          editorconfig-nvim
          leap-nvim
          telescope-zf-native-nvim
          vim-ReplaceWithRegister
          vim-bbye
          vim-dispatch-neovim
          vim-expand-region
          vim-signify
          vim-terraform
        ]
      )
      ++ (with pkgs.vimExtraPlugins; [
        rainbow-delimiters-nvim
      ]);
    mappings = {
      normal = {
        "<leader>u" = {
          action = "vim.cmd.UndotreeToggle";
          desc = "Toggle undotree";
        };
        "<leader>h" = {
          action = "function() vim.api.nvim_command('wincmd h') end";
          desc = "Cursor - Window left";
        };
        "<leader>j" = {
          action = "function() vim.api.nvim_command('wincmd j') end";
          desc = "Cursor - Window down";
        };
        "<leader>k" = {
          action = "function() vim.api.nvim_command('wincmd k') end";
          desc = "Cursor - Window up";
        };
        "<leader>l" = {
          action = "function() vim.api.nvim_command('wincmd l') end";
          desc = "Cursor - Window right";
        };
        "<c-k>" = {
          action = "'<c-u>'";
        };
        "<c-j>" = {
          action = "'<c-d>'";
        };
        "<leader>n" = {
          action = "function() vim.api.nvim_command('nohl') end";
          desc = "nohl";
        };
      };
      visual = {
        "<c-k>" = {
          action = "'<c-u>'";
        };
        "<c-j>" = {
          action = "'<c-d>'";
        };
      };
    };
  };
}
